pub fn app_state() -> &'static ScouterStateExpand description
Global accessor for the application state, ensuring the runtime is initialized once.
pub fn app_state() -> &'static ScouterStateGlobal accessor for the application state, ensuring the runtime is initialized once.